package com.wrj.driver.server.controller;


import cn.hutool.core.collection.CollectionUtil;
import com.wrj.driver.server.dto.QuestionAddDto;
import com.wrj.driver.server.dto.QuestionQueryDto;
import com.wrj.driver.server.exception.BusinessException;
import com.wrj.driver.server.response.BaseResponse;
import com.wrj.driver.server.service.IWrjQuestionService;
import com.wrj.driver.server.vo.QuestionVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;

/**
 * <p>
 * 题库; 前端控制器
 * </p>
 *
 * @author Automated procedures
 * @since 2023-08-10
 */
@Api(tags = "考试题库")
@RestController
@RequestMapping("/wrjQuestion")
@Slf4j
public class WrjQuestionController {

    @Autowired
    private IWrjQuestionService questionService;

    @ApiOperation("根据id获取题目")
    @PostMapping("/queryQuestionById")
    public BaseResponse queryQuestionById(@RequestBody QuestionQueryDto queryDto) {
        log.info("获取题型======>queryDto:{}", queryDto);
        return BaseResponse.success(questionService.queryQuestionById(queryDto));
    }

    @ApiOperation("根据id列表获取题目")
    @PostMapping("/queryQuestionByIdList")
    public BaseResponse queryQuestionByIdList(@RequestBody QuestionQueryDto queryDto) {
        log.info("获取题型======>queryDto:{}", queryDto);
        return BaseResponse.success(questionService.queryQuestionByIdList(queryDto));
    }

    @ApiOperation("根据查询条件获取题目")
    @PostMapping("/queryQuestion")
    public BaseResponse queryQuestion(@RequestBody QuestionQueryDto queryDto) {
        log.info("根据查询条件获取题目======>queryDto:{}", queryDto);
        return BaseResponse.success(questionService.queryQuestion(queryDto));
    }

    @ApiOperation("根据查询条件获取题目Id")
    @PostMapping("/queryQuestionId")
    public BaseResponse queryQuestionId(@RequestBody QuestionQueryDto queryDto) {
        log.info("根据查询条件获取题目Id======>queryDto:{}", queryDto);
        return BaseResponse.success(questionService.queryQuestionId(queryDto));
    }

    @ApiOperation("获取模拟考试题目")
    @PostMapping("/getTestQuestion")
    public BaseResponse getTestQuestion(@RequestBody QuestionQueryDto queryDto) {
        log.info("获取模拟考试题目======>queryDto:{}", queryDto);
        return BaseResponse.success(questionService.getTestQuestion(queryDto));
    }

    @ApiOperation("获取模拟考试题目Id")
    @PostMapping("/getTestQuestionId")
    public BaseResponse getTestQuestionId(@RequestBody QuestionQueryDto queryDto) {
        log.info("根据查询条件获取题目Id======>queryDto:{}", queryDto);
        return BaseResponse.success(questionService.getTestQuestionId(queryDto));
    }


    @ApiOperation("对嘛接口-根据查询条件获取题目")
    @GetMapping("/duima/list")
    public Map listQuestion( QuestionQueryDto queryDto) {
        log.info("获取题型======>queryDto:{}", queryDto);
        Map<String, Object> result = new HashMap<>();
        result.put("code", 200);
        result.put("data", questionService.queryQuestion(queryDto));
        return result;
    }

    @ApiOperation("对嘛接口-修改题库")
    @PutMapping("/duima/update")
    public Map updateQuestion(@RequestBody QuestionVo questionVo) {
        log.info("修改题库======>questionVo:{}", questionVo);
        Map<String, Object> result = new HashMap<>();
        result.put("code", 200);
        result.put("data", questionService.updateQuestion(questionVo));
        return result;
    }

    @ApiOperation("新增题库")
    @PostMapping("/insert")
    public Map insertQuestion(@RequestBody @Valid QuestionAddDto addDto) {
        log.info("新增题库======>QuestionAddDto:{}", addDto);
        Map<String, Object> result = new HashMap<>();
        result.put("code", 200);
        result.put("data", questionService.insertQuestion(addDto));
        return result;
    }

    @ApiOperation("查询各专项分类题目数量")
    @PostMapping("/querySpecialNum")
    public BaseResponse querySpecialNum(@RequestBody QuestionQueryDto queryDto) {
        log.info("查询各专项分类题目数量======>queryDto:{}", queryDto);
        return BaseResponse.success(questionService.querySpecialNum(queryDto));
    }

}
