package com.wrj.driver.server.controller;


import com.wrj.driver.server.dto.SysConfigDto;
import com.wrj.driver.server.entity.WrjSysConfig;
import com.wrj.driver.server.response.BaseResponse;
import com.wrj.driver.server.service.IWrjSysConfigService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Arrays;
import java.util.Map;

/**
 * <p>
 * 系统配置表; 前端控制器
 * </p>
 *
 * @author Automated procedures
 * @since 2023-08-10
 */
@Api(tags = "字典值配置")
@RestController
@RequestMapping("/wrjSysConfig")
@Slf4j
public class WrjSysConfigController {

    @Autowired
    private IWrjSysConfigService configService;

    /**
     * 根据配置key和driverTypeId获取配置信息,配置与无人机无关则driverTypeId为-1
     */
    @ApiOperation("根据配置key和driverTypeId获取配置信息,配置与无人机无关则driverTypeId为-1")
    @GetMapping(value = "/queryConfigByKey")
    public BaseResponse queryConfigByKey(@RequestParam("configKey") String configKey, @RequestParam("driverTypeId") Integer driverTypeId) {
        return BaseResponse.success(configService.queryConfigByKey(configKey, driverTypeId));
    }

    /**
     * 根据配置key和driverTypeId获取配置信息,配置与无人机无关则driverTypeId为-1
     */
    @ApiOperation("根据配置key获取配置值")
    @GetMapping(value = "/queryConfigValueByKey")
    public BaseResponse<String> queryConfigValueByKey(@RequestParam("configKey") String configKey, @RequestParam("driverTypeId") Integer driverTypeId) {

        return BaseResponse.success(configService.queryConfigValueByKey(configKey, driverTypeId));

    }

    /**
     * 根据配置keys和driverTypeId获取配置信息,配置与无人机无关则driverTypeId为-1
     */
    @ApiOperation("根据配置keys和driverTypeId获取配置信息,配置与无人机无关则driverTypeId为-1")
    @GetMapping(value = "/queryConfigByKeys")
    public BaseResponse<Map<String, WrjSysConfig>> queryConfigByKeys(@RequestParam("configKeys") String configKeys, @RequestParam("driverTypeId") Integer driverTypeId) {
        return BaseResponse.success(configService.queryConfigByKeys(Arrays.asList(configKeys.split(",")),driverTypeId));

    }

    @ApiOperation("保存配置")
    @PostMapping("/saveConfig")
    public BaseResponse saveConfig(@RequestBody SysConfigDto configDto){
        return BaseResponse.success(configService.saveConfig(configDto));
    }
}
