package com.wrj.driver.server.filter;

import cn.hutool.core.util.NumberUtil;
import cn.hutool.http.HttpStatus;
import com.wrj.driver.server.constant.Constants;
import com.wrj.driver.server.interceptor.TenantContextHolder;
import org.springframework.core.Ordered;
import org.springframework.core.annotation.Order;
import org.springframework.stereotype.Component;

import javax.servlet.*;
import javax.servlet.annotation.WebFilter;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;

@WebFilter(filterName = "loginFilter",urlPatterns = "/*")
@Component
@Order(Ordered.HIGHEST_PRECEDENCE)
public class HttpFilter implements Filter {


    @Override
    public void init(FilterConfig filterConfig) throws ServletException {
        Filter.super.init(filterConfig);
    }

    @Override
    public void doFilter(ServletRequest servletRequest, ServletResponse servletResponse, FilterChain filterChain) throws IOException, ServletException {
        HttpServletResponse response = (HttpServletResponse) servletResponse;
        response.setHeader("Access-Control-Allow-Origin", "*");
        response.setHeader("Access-Control-Allow-Methods", "POST, GET, OPTIONS, DELETE, HEAD");
        response.setHeader("Access-Control-Max-Age", "3600");
        response.setHeader("Access-Control-Allow-Headers", "*");

        //获取租户
        TenantContextHolder.setTenantId(getTenantId((HttpServletRequest) servletRequest));

        if ("OPTIONS".equalsIgnoreCase(((HttpServletRequest) servletRequest).getMethod())){
            response.setStatus(HttpStatus.HTTP_OK);
            return;
        } else {
            filterChain.doFilter(servletRequest, servletResponse);
        }
    }

    @Override
    public void destroy() {
        Filter.super.destroy();
    }

    public static Long getTenantId(HttpServletRequest request) {
        String tenantId = request.getHeader(Constants.HEADER_TENANT_ID);
        return NumberUtil.isNumber(tenantId) ? Long.valueOf(tenantId) : null;
    }
}
