package com.wrj.driver.server.interceptor;

import com.alibaba.ttl.TransmittableThreadLocal;

public class TenantContextHolder {

    /**
     * 当前租户编号
     */
    private static final ThreadLocal<Long> TENANT_ID = new TransmittableThreadLocal<>();

    /**
     * 当前租户编号
     */
    private static final ThreadLocal<Long> INSTANCE_ID = new TransmittableThreadLocal<>();

    /**
     * 是否忽略租户
     */
    private static final ThreadLocal<Boolean> IGNORE = new TransmittableThreadLocal<>();

    /**
     * 获得租户编号
     *
     * @return 租户编号
     */
    public static Long getTenantId() {
        return TENANT_ID.get();
    }


    /**
     * 获得服务实例编号
     *
     * @return 租户编号
     */
    public static final Long getInstanceId() {
        return INSTANCE_ID.get();
    }

    /**
     * 获得租户编号。如果不存在，则抛出 NullPointerException 异常
     *
     * @return 租户编号
     */
    public static Long getRequiredTenantId() {
        Long tenantId = getTenantId();
//        if (tenantId == null) {
//            throw new NullPointerException("TenantContextHolder 不存在租户编号!");
//        }
        return tenantId;
    }

    public static void setTenantId(Long tenantId) {
        TENANT_ID.set(tenantId);
    }

    public static void setIgnore(Boolean ignore) {
        IGNORE.set(ignore);
    }

    public static void setInstanceId(Long instanceId) {
        INSTANCE_ID.set(instanceId);
    }

    /**
     * 当前是否忽略租户
     *
     * @return 是否忽略
     */
    public static boolean isIgnore() {
        return Boolean.TRUE.equals(IGNORE.get());
    }

    public static void clear() {
        TENANT_ID.remove();
        IGNORE.remove();
        INSTANCE_ID.remove();
    }
}
