package com.wrj.driver.server.service.impl;

import cn.hutool.core.collection.CollectionUtil;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.wrj.driver.server.dto.SecurityUser;
import com.wrj.driver.server.dto.TestQueryDto;
import com.wrj.driver.server.entity.*;
import com.wrj.driver.server.service.*;
import com.wrj.driver.server.vo.ExamParam;
import com.wrj.driver.server.vo.TestScoreVO;
import com.wrj.driver.server.dto.TestSubmitDto;
import com.wrj.driver.server.enums.StatusEnum;
import com.wrj.driver.server.exception.BusinessException;
import com.wrj.driver.server.mapper.WrjQuestionTestMapper;
import com.wrj.driver.server.response.BaseResponse;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.wrj.driver.server.util.SecurityUtil;
import com.wrj.driver.server.vo.TestTotalVo;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.StringUtils;

import java.time.LocalDateTime;
import java.util.List;
import java.util.Map;
import java.util.OptionalDouble;
import java.util.stream.Collectors;

/**
 * <p>
 * 模拟考试成绩表; 服务实现类
 * </p>
 *
 * @author Automated procedures
 * @since 2023-08-10
 */
@Service
public class WrjQuestionTestServiceImpl extends ServiceImpl<WrjQuestionTestMapper, WrjQuestionTest> implements IWrjQuestionTestService {


    @Autowired
    private IWrjSysConfigService configService;

    @Override
    @Transactional(rollbackFor = Exception.class)
    public BaseResponse testSubmit(TestSubmitDto submitDto) {

        WrjQuestionTest questionTest = new WrjQuestionTest();
        BeanUtils.copyProperties(submitDto, questionTest);
        questionTest.setUserId(SecurityUtil.getUserId())
                .setTypeId(submitDto.getDriverTypeId())
                .setCreateTime(LocalDateTime.now());
        boolean save = this.save(questionTest);
        if (!save){
            throw new BusinessException("考试成绩提交失败");
        }
        return new BaseResponse(StatusEnum.SUCCESS.getCode(), "", questionTest);
    }

    @Override
    public TestTotalVo testTotal(TestQueryDto queryDto) {
        TestTotalVo testTotalVo = new TestTotalVo();
        LambdaQueryWrapper<WrjQuestionTest> queryWrapper = new LambdaQueryWrapper<WrjQuestionTest>()
                .eq(WrjQuestionTest::getTypeId, queryDto.getDriverTypeId())
                .eq(WrjQuestionTest::getUserId, SecurityUtil.getUserId())
                .orderByDesc(WrjQuestionTest::getCreateTime);

        List<WrjQuestionTest> list = this.list(queryWrapper);
        Long passNum = list.stream().filter(s -> s.getScore() >= 90).count();
        testTotalVo.setTestNum(list.size())
                .setPassNum(passNum.intValue());
        //取最近的五次
        if (CollectionUtil.isNotEmpty(list) && list.size() > 5) {
            list = list.subList(0, 5);
        }
        List<WrjQuestionTest> recentTestList = CollectionUtil.reverse(list);
        //最近五次的平均分
        OptionalDouble averaged = recentTestList.stream().mapToInt(WrjQuestionTest::getScore).average();
        Integer average = 0;
        if (averaged.isPresent()){
            Double averageScore = averaged.getAsDouble();
            average = averageScore.intValue();
        }
        testTotalVo.setRecentTestList(recentTestList)
                .setRecentAverageScore(average);
        return testTotalVo;
    }

    @Override
    public List<TestScoreVO> getTestScore(TestQueryDto queryDto) {
        SecurityUser loginUser = SecurityUtil.getLoginUser();
        queryDto.setUserId(loginUser.getUserId());
        //查询当前用户的考试成绩
        List<TestScoreVO> data = this.getBaseMapper().getTestScore(queryDto);
        //查询考试配置
        List<WrjSysConfig> configList = configService.queryConfigByKey("ExamParams");
        Map<Integer, String> configMap = configList.stream().collect(Collectors.toMap(WrjSysConfig::getDriverTypeId, WrjSysConfig::getConfigJson));

        data.forEach(score -> {
            String setting = configMap.get(score.getDriverTypeId());
            score.setIsPass("不合格");
            if (!StringUtils.isEmpty(setting)){
                List<ExamParam> examParams = JSONObject.parseArray(setting, ExamParam.class);
                if (examParams != null && !examParams.isEmpty()){
                    ExamParam examParam = examParams.stream().filter(d -> d.getDriverTypeId().equals(score.getDriverTypeId())).findFirst().orElse(null);
                    if (examParam != null && examParam.getOptions().getBaseScore()<= score.getScore()){
                        score.setIsPass("合格");
                    }
                }
            }
        });
        return data;
    }
}
